California Secretary of State - CalAccess - Campaign Finance

Advanced Search
| Candidates & Elected Officials
Propositions & Ballot Measures
Committees, Parties, Major Donors & Slate Mailers
Daily/Late/ Special Filings
| Campaign Finance: PROPOSITION 025 - CHANGES LEGISLATIVE VOTE REQUIREMENT TO PASS A BUDGET FROM TWO-THIRDS TO A SIMPLE MAJORITY. RETAINS TWO-THIRDS VOTE REQUIREMENT FOR TAXES. View Information: General Information Late Independent Expenditures Affecting This Measure
How much money is being raised and spent to pass or defeat California propositions and ballot measures, and what are the sources of the money? Check here to follow the money trail.
Committees formed to support or oppose the ballot measure.
COMMITTEE ID | COMMITTEE NAME | COMMITTEE POSITION
1329182 | CALIFORNIA COALITION FOR LEADERSHIP AND ACCOUNTABILITY IN BUDGET AND REDISTRICTING, YES ON 25 & 27, NO ON 20 | SUPPORT
COMMITTEE ID | COMMITTEE NAME | COMMITTEE POSITION
1229504 | AMERICAN FEDERATION OF TEACHERS, AFL-CIO (YES ON 25) | SUPPORT
COMMITTEE ID | COMMITTEE NAME | COMMITTEE POSITION
1323713 | YES ON 25, CITIZENS FOR AN ON-TIME BUDGET SPONSORED BY TEACHERS, NURSES, FIREFIGHTERS AND OTHER PUBLIC GROUPS | SUPPORT
COMMITTEE ID | COMMITTEE NAME | COMMITTEE POSITION
1323934 | STOP HIDDEN TAXES - NO ON 25 / YES ON 26, A COALITION OF TAXPAYERS AND EMPLOYERS | OPPOSE
COMMITTEE ID | COMMITTEE NAME | COMMITTEE POSITION
1331815 | CALIFORNIA ALLIANCE ACTION FUND: A COMMITTEE SPONSORED BY SOCIAL JUSTICE ORGANIZATIONS FOR PROPOSITIONS 24, 25 AND AGAINST PROPOSITIONS 23, 26 | SUPPORT
COMMITTEE ID | COMMITTEE NAME | COMMITTEE POSITION
1240104 | CALIFORNIA FEDERATION OF TEACHERS COPE PROP/BALLOT COMMITTEE - YES ON 25 | SUPPORT
COMMITTEE ID | COMMITTEE NAME | COMMITTEE POSITION
1270683 | SMALL BUSINESS ACTION COMMITTEE PAC, YES ON 20 & 26, NO ON 25 & 27 | OPPOSE
COMMITTEE ID | COMMITTEE NAME | COMMITTEE POSITION
1332721 | LOS ANGELES COUNTY FEDERATION OF LABOR, AFL-CIO, YES ON 24 AND 25 | SUPPORT